import { __awaiter, __decorate } from "tslib";
import { Connect } from '@genesislcap/foundation-comms';
import { getActionsMenuDef } from '@genesislcap/foundation-zero-grid-pro';
import { customElement, FASTElement, observable } from '@microsoft/fast-element';
import { actionsOpenIcon } from '../../assets/images';
import { ReportingEventListeners } from '../../routes/reporting-home/types';
import { ColorHEX } from '../../styles';
import { ListStyles as styles } from './list.styles';
import { ListTemplate as template } from './list.template';
const name = 'reporting-list';
let List = class List extends FASTElement {
    constructor() {
        super(...arguments);
        this.userInteractedRow = {};
        this.selectedRows = [];
        this.slectionEvent = new CustomEvent('rowSelectionEvent', {
            detail: { selectedRows: () => this.selectedRows },
        });
        this.runReport = (data) => {
            this.$emit(ReportingEventListeners.runReport, data);
        };
        this.actionsMenuSlottedConfig = getActionsMenuDef([
            {
                name: 'Edit',
                callback: (rowData) => {
                    this.$emit(ReportingEventListeners.editReport, rowData);
                },
            },
            {
                name: 'Run',
                callback: (rowData) => {
                    this.runReport(rowData);
                },
            },
            {
                name: 'Delete',
                callback: (rowData) => {
                    this.delete(rowData);
                },
                color: ColorHEX.orange,
            },
        ], {
            width: 60,
            headerName: '',
            filter: false,
            sortable: false,
            resizable: false,
            suppressMenu: true,
            cellStyle: {
                display: 'flex',
                justifyContent: 'center',
                alignItems: 'center',
                overflow: 'visible',
            },
        }, actionsOpenIcon());
    }
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            _super.connectedCallback.call(this);
            this.grid.addEventListener('onGridReady', () => {
                window.addEventListener('resize', () => {
                    setTimeout(() => {
                        this.grid.gridApi.sizeColumnsToFit();
                    });
                });
                this.grid.gridApi.addEventListener('firstDataRendered', () => {
                    this.grid.gridApi.sizeColumnsToFit();
                });
                this.grid.gridApi.addEventListener('selectionChanged', () => {
                    this.selectedRows = this.grid.gridApi.getSelectedRows();
                    this.dispatchEvent(this.slectionEvent);
                });
            });
        });
    }
    delete(rowData) {
        return __awaiter(this, void 0, void 0, function* () {
            let notification = null;
            const { REPORT_ID } = rowData;
            const result = yield this.connect.commitEvent('EVENT_SAVED_REPORTS_DELETE', {
                DETAILS: { REPORT_ID },
                IGNORE_WARNINGS: true,
                VALIDATE: false,
            });
            result.MESSAGE_TYPE === 'EVENT_ACK'
                ? (notification = {
                    message: `'${rowData.REPORT_NAME}' was deleted`,
                    title: 'Success:',
                    type: 'success',
                })
                : (notification = {
                    message: `'${rowData.REPORT_NAME}' was not deleted due to the following error "${result.ERROR[0].TEXT}"`,
                    title: 'Error:',
                    type: 'warning',
                });
            this.$emit(ReportingEventListeners.notify, notification);
        });
    }
    batchDelete() {
        // service does not accept arrays so have to loop
        this.selectedRows.forEach((rowData) => this.delete(rowData));
    }
};
__decorate([
    Connect
], List.prototype, "connect", void 0);
__decorate([
    observable
], List.prototype, "userInteractedRow", void 0);
__decorate([
    observable
], List.prototype, "selectedRows", void 0);
List = __decorate([
    customElement({
        name,
        template,
        styles,
    })
], List);
export { List };
