import { __decorate } from "tslib";
import { attr, css, customElement, FASTElement, html, when } from '@microsoft/fast-element';
import { ColorHEX } from '../styles';
const { cyan } = ColorHEX;
var Divider;
(function (Divider) {
    Divider["equal"] = "hyphen";
    Divider["leftMain"] = "";
    Divider["rightMain"] = "hyphen";
})(Divider || (Divider = {}));
const name = 'layout-two-pane-horizontal';
const styles = css `
  .container {
    align-items: stretch;
    column-gap: 4rem;
    display: grid;
    height: 100%;
  }

  .container.equal {
    grid-template-columns: 1fr 1fr;
  }

  .container.left-main {
    grid-template-columns: 3fr 1fr;
  }

  .container.right-main {
    grid-template-columns: 1fr 3fr;
  }

  .left {
    position: relative;
  }

  .left .divider {
    display: flex;
    font-size: 3.2rem;
    justify-content: center;
    position: absolute;
    right: -4rem;
    top: 50%;
    width: 4rem;
    color: ${cyan};
  }
`;
const template = html `
  <div class="container ${(x) => x.splitRatio}" part="split-container">
    <section class="left" part="left-section">
      <slot name="left-section"></slot>

      ${when((x) => !x.hideDivider, html `
          <div class="divider" part="divider">
            <slot name="divider">
              <zero-icon name="chevron-right"></zero-icon>
            </slot>
          </div>
        `)}
    </section>

    <section class="right" part="right-section">
      <slot name="right-section"></slot>
    </section>
  </div>
`;
let LayoutTwoPaneHorizontal = class LayoutTwoPaneHorizontal extends FASTElement {
    constructor() {
        super(...arguments);
        this.hideDivider = false;
        this.splitRatio = 'equal';
    }
};
__decorate([
    attr({ mode: 'boolean' })
], LayoutTwoPaneHorizontal.prototype, "hideDivider", void 0);
__decorate([
    attr
], LayoutTwoPaneHorizontal.prototype, "splitRatio", void 0);
LayoutTwoPaneHorizontal = __decorate([
    customElement({
        name,
        styles,
        template,
    })
], LayoutTwoPaneHorizontal);
export { LayoutTwoPaneHorizontal };
