import { __awaiter, __decorate } from "tslib";
import { Connect, DatasourceDefaults } from '@genesislcap/foundation-comms';
import { customElement, observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { ReportingHomeStyles as styles } from './reporting-home-styles';
import { ReportingHomeTemplate as template } from './reporting-home-template';
import { ReportingEventListeners } from './types';
const name = 'reporting-home';
let ReportingHome = class ReportingHome extends FoundationElement {
    constructor() {
        super(...arguments);
        this.fields = [];
        this.selectedRows = [];
        this.activeReport = {};
        this.notifications = [];
    }
    enter(phase) {
        var _a, _b, _c, _d;
        return __awaiter(this, void 0, void 0, function* () {
            this.datasourceSettings = {
                maxRows: (_b = (_a = phase.route.settings) === null || _a === void 0 ? void 0 : _a.maxRows) !== null && _b !== void 0 ? _b : DatasourceDefaults.MAX_ROWS_250,
                maxView: (_d = (_c = phase.route.settings) === null || _c === void 0 ? void 0 : _c.maxView) !== null && _d !== void 0 ? _d : DatasourceDefaults.MAX_VIEW_1000,
            };
        });
    }
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            _super.connectedCallback.call(this);
            this.reportsGrid.addEventListener('rowSelectionEvent', (e) => {
                this.selectedRows = e.detail.selectedRows();
            });
            this.addEventListener(ReportingEventListeners.notify, (e) => {
                this.notifications = [...this.notifications, e.detail];
            });
            this.addEventListener(ReportingEventListeners.listReports, (e) => {
                this.setPageTab('list-reports');
                this.activeReport = {};
            });
            this.reportsGrid.addEventListener(ReportingEventListeners.runReport, (e) => {
                this.run(e.detail);
            });
            this.reportsGrid.addEventListener(ReportingEventListeners.editReport, (e) => {
                this.edit(e.detail);
            });
        });
    }
    // TODO: use const for tab identifiers
    create() {
        this.activeReport = {};
        this.setPageTab('create-edit-report');
    }
    edit(rowData) {
        this.activeReport = Object.assign(Object.assign({}, rowData), { REPORT_COLUMNS: JSON.parse(rowData['REPORT_COLUMNS']) });
        this.setPageTab('create-edit-report');
    }
    run(rowData) {
        return __awaiter(this, void 0, void 0, function* () {
            this.activeReport = Object.assign(Object.assign({}, rowData), { REPORT_COLUMNS: JSON.parse(rowData['REPORT_COLUMNS']) });
            this.setPageTab('run-report');
        });
    }
    setPageTab(tab) {
        this.tabs.activeid = tab;
    }
    getFields(resourceName) {
        return __awaiter(this, void 0, void 0, function* () {
            const temp = yield this.connect.getMetadata(resourceName);
            for (let i = 0; i < temp.FIELD.length; i += 1) {
                this.fields.push(temp.FIELD[i].NAME);
            }
            this.listBox.hidden = false;
        });
    }
};
__decorate([
    Connect
], ReportingHome.prototype, "connect", void 0);
__decorate([
    observable
], ReportingHome.prototype, "fields", void 0);
__decorate([
    observable
], ReportingHome.prototype, "selectedRows", void 0);
__decorate([
    observable
], ReportingHome.prototype, "activeReport", void 0);
__decorate([
    observable
], ReportingHome.prototype, "notifications", void 0);
__decorate([
    observable
], ReportingHome.prototype, "datasourceSettings", void 0);
ReportingHome = __decorate([
    customElement({
        name,
        template,
        styles,
    })
], ReportingHome);
export { ReportingHome };
