import { PackageConfig, defaultAuditThresholds } from '@genesislcap/foundation-testing/e2e';
import type { Locator, Page } from '@playwright/test';

export class FoundationReportPage {
  config: PackageConfig;
  port: number;
  page: Page;
  notificationContainer: Locator;
  toast: Locator;
  header: Locator;
  reportTitle: Locator;
  controls: Locator;
  deleteReportsButton: Locator;
  addReportButton: Locator;
  tabs: Locator;
  reportingTab: Locator;
  listReportsTab: Locator;
  createEditReportTab: Locator;
  runReportTab: Locator;
  listReportsPanel: Locator;
  createEditReportPanel: Locator;
  reportPreviewPanel: Locator;
  reportList: Locator;
  createEditReportComponent: Locator;
  reportPreviewComponent: Locator;

  constructor(config: PackageConfig, port: number, page: Page) {
    this.config = config;
    this.port = port;
    this.page = page;
    /**
     * Locate fields not guarded by conditionals upfront, and the remaining on-demand
     */
    this.notificationContainer = this.page.locator('data-test-id=notification-container');
    this.toast = this.page.locator('data-test-id=toast');
    this.header = this.page.locator('data-test-id=header');
    this.reportTitle = this.page.locator('data-test-id=report-title');
    this.controls = this.page.locator('data-test-id=controls');
    this.deleteReportsButton = this.page.locator('data-test-id=delete-reports-button');
    this.addReportButton = this.page.locator('data-test-id=add-report-button');
    this.tabs = this.page.locator('data-test-id=tabs');
    this.reportingTab = this.page.locator('data-test-id=reporting-tab');
    this.listReportsTab = this.page.locator('data-test-id=list-reports-tab');
    this.createEditReportTab = this.page.locator('data-test-id=create-edit-report-tab');
    this.runReportTab = this.page.locator('data-test-id=run-report-tab');
    this.listReportsPanel = this.page.locator('data-test-id=list-reports-panel');
    this.createEditReportPanel = this.page.locator('data-test-id=create-edit-report-panel');
    this.reportPreviewPanel = this.page.locator('data-test-id=report-preview-panel');
    this.reportList = this.page.locator('data-test-id=report-list');
    this.createEditReportComponent = this.page.locator('data-test-id=create-edit-report-component');
    this.reportPreviewComponent = this.page.locator('data-test-id=report-preview-component');
  }

  async goto() {
    await this.page.goto('/');
  }

  async audit() {
    const { playAudit } = await import('playwright-lighthouse');
    await playAudit({
      page: this.page,
      port: this.port,
      thresholds: defaultAuditThresholds, // TODO: this should be coming from foundation-testing/src/playwright/test.ts base config
    });
  }
}
